# pyqt-ani-button
PyQt QPushButton for animation

## Requirements
* PyQt5 >= 5.8

## Setup
`python -m pip install pyqt-ani-button`

## Included Package
* <a href="https://github.com/yjg30737/pyqt-ani-abstractbutton.git">pyqt-ani-abstractbutton</a>
